#########################################################################################################
#
# Analysis for the paper Automatic Mechanism for Measuring SUbjective Unit of Discomfort
# 2018 TUDelft
# This script will generate output: "data_analyses_automatic_mechanism_for_measuring_sUbjective_unit_of_discomfort.txt" 
#
# Required datafiles:
# - data_wide_process.csv
# - data_long_process.csv
# 
#########################################################################################################

# Adjust this to root folder that contain data files
setwd("D:/Surfdrive/PhD Research/#1/R/")

# Capture all the output to a file
sink("data_analyses_automatic_mechanism_for_measuring_subjective_unit_of_discomfort.txt")

# Print R version and operating system version used by this data analyses
sessionInfo()

############################################### LIBRARIES ###############################################
# Libraries used for this analyses 

# if you not have one of this library, you can run this command to install your specific library
# install.packages("ez", dependencies = TRUE)
library(reshape2)
library(ez)

# Data requirements for this analyses:
# - data_wide_process.csv
# - data_long_process.csv

dataset_explore <- read.csv("data_wide_process.csv")
dataset_coder <- read.csv("data_long_process.csv")


############################################### FUNCTIONS ###############################################
# Collection of functions used for this study

# print the mean and standard deviation
mean_sd <- function(data, text){
  cat(text," Mean: ", mean(data, na.rm = TRUE), " SD: ", sd(data, na.rm=TRUE), "\n") 
}

# median
mean_median_iqr <- function(data, text){
  cat(text, "Mean: ", mean(data, na.rm = TRUE), "Median: ", median(data, na.rm = TRUE), " IQR: ", IQR(data, na.rm = TRUE, type = 6), "\n")
}

# count specific gender variable
count_female <- function(x){
  return (length(x[x == "female"]))
}

pearson_cor <- function(data1, data2, text) {
  r <- cor.test(data1, data2, method = "pearson", paired = TRUE, exact = FALSE, continuity = FALSE, conf.level = 0.95)
  cat(text, "\n")
  cat("Pearson's correlation:", r$estimate, "t:", r$statistic, "df:", r$parameter, "p-value:", r$p.value, "\n")
} 

friedman_test <- function(data1, data2, data3, text) {
  ft <- data.frame (data1, data2, data3)
  ftest <- as.matrix(ft)
  cat(text, "\n")
  friedman.test(ftest)
}

wilcox_test <- function(data1, data2, text) {
  cat("Wilcoxon Signed-Rank test:", text, "\n")
  wilcox_result <- wilcox.test(data1, data2, alternative = "two.sided", paired = TRUE, exact = FALSE, correct = FALSE, na.action = na.exclude)
  p <- wilcox_result$p.value
  z <- qnorm(wilcox_result$p.value/2)
  cat("Z value = ", z, "and p-value = ", p, "\n")
}

#transform Maindata dataframe for a wide format to long format
tranformToLong <- function(mshort,idlist, measurelist,measurename)
{ 
  msubset <- subset(mshort, select = c(idlist,measurelist))
  mlong <- melt(msubset, id=idlist, measured = measurelist)
  names(mlong) <- c("pid","condition",measurename)
  return(mlong)
}

#print output ezANOVA, including effectsize eta, and Greenhouse-Geisser corrected dfs
print_ezANOVA <- function(m){
  print(m)
  m$ANOVA$eta <- m$ANOVA$SSn/(m$ANOVA$SSn + m$ANOVA$SSd)
  for (i in 1:length(m$ANOVA$Effect)) 
  { cat(m$ANOVA$Effect[i]," : eta ", m$ANOVA$eta[i]," \n")
  }
  cat("see ges-value for Generalized Eta-Squared) \n\n")
  
  cat("Greenhouse-Geisser corrected Dfs. \n") 
  for (i in 1:length(m$`Sphericity Corrections`$Effect))
  { 
    for (j in 1:length(m$ANOVA$Effect)) {
      if (m$ANOVA$Effect[j] == m$`Sphericity Corrections`$Effect[i]){
        m$`Sphericity Corrections`$DFn_G[i] <- m$ANOVA$DFn[j] * m$`Sphericity Corrections`$GGe[i]
        m$`Sphericity Corrections`$DFd_G[i] <- m$ANOVA$DFd[j] * m$`Sphericity Corrections`$GGe[i]
        cat(m$`Sphericity Corrections`$Effect[i],
            " numerator ", m$`Sphericity Corrections`$DFn_G[i], " , denominator ", m$`Sphericity Corrections`$DFd_G[i], "\n")
      }
    }
  }
}

#########################################################################################################

cat("############################################### ANALYSES ###############################################\n\n")

cat("Note:\n")
cat("Condition 1 = Dialog dependent\n")
cat("Condition 2 = Speech dependent\n")
cat("Condition 3 = Context Independent\n\n")

cat("\n########### Section 1. Methods ###############\n\n")
cat("\n Total number of participants: ", length(dataset_explore$pid), ". Number of females: ", count_female(dataset_explore$gender), "\n")
mean_sd(dataset_explore$age, "Age of participants")

cat("\n########### Section 2. Results ###############\n\n")
# convert pid into factor
dataset_explore$pid <- factor(dataset_explore$pid)

cat("SEQ analyses\n\n")
Maindatalong_SEQ <- tranformToLong(dataset_explore, c("pid"), c("total_seq_cond1", "total_seq_cond2", "total_seq_cond3"), "seq")
seq_model <- ezANOVA(data = Maindatalong_SEQ, dv = .(seq), wid = .(pid), within = .(condition), detailed = TRUE, type =3)
print_ezANOVA(seq_model)

cat("\nDEQ analyses\n\n")
Maindatalong_DEQ <- tranformToLong(dataset_explore,c("pid"), c("total_deq_cond1", "total_deq_cond2", "total_deq_cond3"), "deq")
deq_model <- ezANOVA(data = Maindatalong_DEQ, dv = .(deq), wid = .(pid), within = .(condition), detailed = TRUE, type =3)
print_ezANOVA(deq_model)

cat("\nIPQ analyses\n\n")
Maindatalong_IPQ <- tranformToLong(dataset_explore,c("pid"), c("total_ipq_cond1", "total_ipq_cond2", "total_ipq_cond3"), "ipq")
ipq_model <- ezANOVA(data = Maindatalong_IPQ, dv = .(ipq), wid = .(pid), within = .(condition), detailed = TRUE, type =3)
print_ezANOVA(ipq_model)

cat("\nTable 1. Mean (SD) of measure for three timing mechanism \n\n")
# Total SEQ
mean_sd(dataset_explore$total_seq_cond1, "Total SEQ in dialog dependent =")
mean_sd(dataset_explore$total_seq_cond2, "Total SEQ in speech dependent =")
mean_sd(dataset_explore$total_seq_cond3, "Total SEQ in context independent =")
# Total DEQ
mean_sd(dataset_explore$total_deq_cond1, "Total DEQ in dialog dependent =")
mean_sd(dataset_explore$total_deq_cond2, "Total DEQ in speech dependent =")
mean_sd(dataset_explore$total_deq_cond3, "Total DEQ in context independent =")
# Total IPQ
mean_sd(dataset_explore$total_ipq_cond1, "Total IPQ in dialog dependent =")
mean_sd(dataset_explore$total_ipq_cond2, "Total IPQ in speech dependent =")
mean_sd(dataset_explore$total_ipq_cond3, "Total IPQ in context independent =")

# Median and IQR
cat("\nTable 2. Mean, Median (IQR) and interobserver agreement of the relative frequency for 5 dialogue replies in 3 conditions \n")
# Mean, Median (IQR) dialogue dependent
cat("Note: \n")
cat("For the paper, we only wrote the result of Median and IQR only in the Table 2. \n")
cat("For PhD thesis, we wrote the more complete analyses including the mean, median and IQR \n\n")
mean_median_iqr(dataset_explore$avg_relfreq_cond1_detail, "Mean, Median & IQR of [detail answer] in dialog dependent = ") 
mean_median_iqr(dataset_explore$avg_relfreq_cond1_normal, "Mean, Median & IQR of [normal answer] in dialog dependent = ")
mean_median_iqr(dataset_explore$avg_relfreq_cond1_short, "Mean, Median & IQR of [short answer] in dialog dependent = ")
mean_median_iqr(dataset_explore$avg_relfreq_cond1_dont, "Mean, Median & IQR of [dont know answer] in dialog dependent = ")
mean_median_iqr(dataset_explore$avg_relfreq_cond1_lost, "Mean, Median & IQR of [lost-dialogue answer] in dialog dependent = ")
# Mean, Median (IQR) speech dependent
mean_median_iqr(dataset_explore$avg_relfreq_cond2_detail, "Mean, Median & IQR of [detail answer] in speech dependent = ")
mean_median_iqr(dataset_explore$avg_relfreq_cond2_normal, "Mean, Median & IQR of [normal answer] in speech dependent = ")
mean_median_iqr(dataset_explore$avg_relfreq_cond2_short, "Mean, Median & IQR of [short answer] in speech dependent = ")
mean_median_iqr(dataset_explore$avg_relfreq_cond2_dont, "Mean, Median & IQR of [dont know answer] in speech dependent = ")
mean_median_iqr(dataset_explore$avg_relfreq_cond2_lost, "Mean, Median & IQR of [lost-dialogue answer] in speech dependent = ")
# Mean, Median (IQR) context independent
mean_median_iqr(dataset_explore$avg_relfreq_cond3_detail, "Mean, Median & IQR of [detail answer] in context independent = ")
mean_median_iqr(dataset_explore$avg_relfreq_cond3_normal, "Mean, Median & IQR of [normal answer] in context independent = ")
mean_median_iqr(dataset_explore$avg_relfreq_cond3_short, "Mean, Median & IQR of [short answer] in context independent = ")
mean_median_iqr(dataset_explore$avg_relfreq_cond3_dont, "Mean, Median & IQR of [dont know answer] in context independent = ")
mean_median_iqr(dataset_explore$avg_relfreq_cond3_lost, "Mean, Median & IQR of [lost-dialogue answer] in context independent = ")

# Pearson corelation 
cat("\nInter-observer agreement was evaluated using Pearson's correlation. \n\n")
# source: https://www.r-bloggers.com/
# Detail answer
pearson_cor(dataset_coder$relfreq_coder1_detail, dataset_coder$relfreq_coder2_detail, "Detail answer: coder 1 and coder 2")
pearson_cor(dataset_coder$relfreq_coder1_detail, dataset_coder$relfreq_coder3_detail, "Detail answer: coder 1 and coder 3")
pearson_cor(dataset_coder$relfreq_coder2_detail, dataset_coder$relfreq_coder3_detail, "Detail answer: coder 2 and coder 3")
# Normal answer
pearson_cor(dataset_coder$relfreq_coder1_normal, dataset_coder$relfreq_coder2_normal, "Normal answer: coder 1 and coder 2")
pearson_cor(dataset_coder$relfreq_coder1_normal, dataset_coder$relfreq_coder3_normal, "Normal answer: coder 1 and coder 3")
pearson_cor(dataset_coder$relfreq_coder2_normal, dataset_coder$relfreq_coder3_normal, "Normal answer: coder 2 and coder 3")
# Short answer
pearson_cor(dataset_coder$relfreq_coder1_short, dataset_coder$relfreq_coder2_short, "Short answer: coder 1 and coder 2")
pearson_cor(dataset_coder$relfreq_coder1_short, dataset_coder$relfreq_coder3_short, "Short answer: coder 1 and coder 3")
pearson_cor(dataset_coder$relfreq_coder2_short, dataset_coder$relfreq_coder3_short, "Short answer: coder 2 and coder 3")
# Don't know answer
pearson_cor(dataset_coder$relfreq_coder1_dont, dataset_coder$relfreq_coder2_dont, "Dont know answer: coder 1 and coder 2")
pearson_cor(dataset_coder$relfreq_coder1_dont, dataset_coder$relfreq_coder3_dont, "Dont know answer: coder 1 and coder 3")
pearson_cor(dataset_coder$relfreq_coder2_dont, dataset_coder$relfreq_coder3_dont, "Dont know answer: coder 2 and coder 3")
# Lost in the dialog
pearson_cor(dataset_coder$relfreq_coder1_lost, dataset_coder$relfreq_coder2_lost, "Lost in the dialog: coder 1 and coder 2")
pearson_cor(dataset_coder$relfreq_coder1_lost, dataset_coder$relfreq_coder3_lost, "Lost in the dialog: coder 1 and coder 3")
pearson_cor(dataset_coder$relfreq_coder2_lost, dataset_coder$relfreq_coder3_lost, "Lost in the dialog: coder 2 and coder 3")

# Friedman Rank Sum Test
cat("\nTesting the overall effect of the timing mechanism on participants dialogues replies \n")
cat("Friedman Rank Sum Test \n\n")
# Detail answer
friedman_test(dataset_explore$avg_relfreq_cond1_detail, dataset_explore$avg_relfreq_cond2_detail, dataset_explore$avg_relfreq_cond3_detail, "Relative freq. Friedman test detail answer in 3 conditions")
# Normal answer
friedman_test(dataset_explore$avg_relfreq_cond1_normal, dataset_explore$avg_relfreq_cond2_normal, dataset_explore$avg_relfreq_cond3_normal, "Relative freq. Friedman test normal answer in 3 conditions")
# Short answer
friedman_test(dataset_explore$avg_relfreq_cond1_short, dataset_explore$avg_relfreq_cond2_short, dataset_explore$avg_relfreq_cond3_short, "Relative freq. Friedman test short answer in 3 conditions")
# Dont know answer
friedman_test(dataset_explore$avg_relfreq_cond1_dont, dataset_explore$avg_relfreq_cond2_dont, dataset_explore$avg_relfreq_cond3_dont, "Relative freq. Friedman test don't know answer in 3 conditions")
# Lost in the dialog
friedman_test(dataset_explore$avg_relfreq_cond1_lost, dataset_explore$avg_relfreq_cond2_lost, dataset_explore$avg_relfreq_cond3_lost, "Relative freq. Friedman lost in the dialog in 3 conditions")

# Wilcoxon test
# Note: The Z score can in principle be extracted from the p value (qnorm(p/2)
# Source: http://r.789695.n4.nabble.com/Simple-General-Statistics-and-R-question-with-3-line-example-get-z-value-from-pairwise-wilcox-test-td3480967.html

cat("\nWilcoxon Signed-Rank test \n")
cat("For more detailed analysis, paired comparisons with Wilcoxon Signed-Rank test were conducted \n\n")
# Detail answer
#wilcox_test(dataset_explore$avg_relfreq_cond1_detail, dataset_explore$avg_relfreq_cond2_detail, "detail answer between condition 1 and condition 2")
#wilcox_test(dataset_explore$avg_relfreq_cond1_detail, dataset_explore$avg_relfreq_cond3_detail, "detail answer between condition 1 and condition 3")
#wilcox_test(dataset_explore$avg_relfreq_cond2_detail, dataset_explore$avg_relfreq_cond3_detail, "detail answer between condition 2 and condition 3")
# Normal answer
cat("*Wilcoxon Signed-Rank test: Normal answer*\n")
wilcox_test(dataset_explore$avg_relfreq_cond1_normal, dataset_explore$avg_relfreq_cond2_normal, "normal answer between condition 1 and condition 2")
wilcox_test(dataset_explore$avg_relfreq_cond1_normal, dataset_explore$avg_relfreq_cond3_normal, "normal answer between condition 1 and condition 3")
wilcox_test(dataset_explore$avg_relfreq_cond2_normal, dataset_explore$avg_relfreq_cond3_normal, "normal answer between condition 2 and condition 3")
# Short answer
#wilcox_test(dataset_explore$avg_relfreq_cond1_short, dataset_explore$avg_relfreq_cond2_short, "short answer between condition 1 and condition 2")
#wilcox_test(dataset_explore$avg_relfreq_cond1_short, dataset_explore$avg_relfreq_cond3_short, "short answer between condition 1 and condition 3")
#wilcox_test(dataset_explore$avg_relfreq_cond2_short, dataset_explore$avg_relfreq_cond3_short, "short answer between condition 2 and condition 3")
# Dont know answer
#wilcox_test(dataset_explore$avg_relfreq_cond1_dont, dataset_explore$avg_relfreq_cond2_dont, "dont know answer between condition 1 and condition 2")
#wilcox_test(dataset_explore$avg_relfreq_cond1_dont, dataset_explore$avg_relfreq_cond3_dont, "dont know answer between condition 1 and condition 3")
#wilcox_test(dataset_explore$avg_relfreq_cond2_dont, dataset_explore$avg_relfreq_cond3_dont, "dont know answer between condition 2 and condition 3")
# Lost in the dialog
cat("\n\n*Wilcoxon Signed-Rank test: Lost in the dialog*\n")
wilcox_test(dataset_explore$avg_relfreq_cond1_lost, dataset_explore$avg_relfreq_cond2_lost, "lost in the dialog between condition 1 and condition 2")
wilcox_test(dataset_explore$avg_relfreq_cond1_lost, dataset_explore$avg_relfreq_cond3_lost, "lost in the dialog between condition 1 and condition 3")
wilcox_test(dataset_explore$avg_relfreq_cond2_lost, dataset_explore$avg_relfreq_cond3_lost, "lost in the dialog between condition 2 and condition 3")

cat("\n############################################ END OF ANALYSES ############################################")

######### stop redireting output.
sink()

cat("\n\nOutput of this R script file: data_analyses_automatic_mechanism_for_measuring_sUbjective_unit_of_discomfort.txt") 

