#########################################################################################################
#
# Analysis for the paper Automatic Mechanism for Measuring SUbjective Unit of Discomfort
# 2018 TUDelft
# This script will generate output: "data_explore_automatic_mechanism_for_measuring_sUbjective_unit_of_discomfort.txt" 
#
# Required datafiles:
# - data_wide_process.csv
# - data_long_process.csv
# 
#########################################################################################################

# Adjust this to root folder that contain data files
setwd("D:/Surfdrive/PhD Research/#1/R/")

# Capture all the output to a file
sink("data_explore_automatic_mechanism_for_measuring_subjective_unit_of_discomfort.txt")

# Print R version and operating system version used by this data analyses
sessionInfo()

############################################### LIBRARIES ###############################################
# Libraries used for this analyses 

# if you not have one of this library, you can run this command to install your specific library
# install.packages("ez", dependencies = TRUE)
library(reshape2)
library(car)

# Functions:
histogram <- function (data, title, text){
  hist(data, prob=TRUE, col="grey", main = title, xlab = text)
  lines(density(data, na.rm = TRUE), col="blue", lwd=1) 
  lines(density(data, adjust=2, na.rm = TRUE), lty="dotted", col="darkgreen", lwd=1) 
}

levene_test <- function (data1, data2, text){
  cat(text)
  x <- c(data1, data2)
  group <- as.factor(c(rep(1, length(data1)), rep(2, length(data2))))
  leveneTest(x, group)
}

#########################################################################################################

# Data requirements for this analyses:
# - data_wide_process.csv
# - data_long_process.csv

# Data fields explanation:
#
# File: data_wide_process.csv
# 01. pid: participants ID number
# 02. gender: gender of participants
# 03. age: age of participants
# 04. total_seq_cond1: total of SEQ questinnaires in the condition 1
# 05. total_seq_cond2: total of SEQ questinnaires in the condition 2
# 06. total_seq_cond3: total of SEQ questinnaires in the condition 3
# 07. total_deq_cond1: total of DEQ questinnaires in the condition 1
# 08  total_deq_cond2: total of DEQ questinnaires in the condition 2
# 09. total_deq_cond3: total of DEQ questinnaires in the condition 3
# 10. total_ipq_cond1: total of IPQ questinnaires in the condition 1
# 11. total_ipq_cond1: total of IPQ questinnaires in the condition 2
# 12. total_ipq_cond1: total of IPQ questinnaires in the condition 3
# 13. avg_relfreq_cond1_normal: the average of relative frequency from normal dialogue reply in the condition 1
# 14. avg_relfreq_cond1_short: the average of relative frequency from short dialogue reply in the condition 1
# 15. avg_relfreq_cond1_detail: the average of relative frequency from detail l dialogue reply in the condition 1
# 16. avg_relfreq_cond1_dont: the average of relative frequency from dont dialogue reply in the condition 1
# 17. avg_relfreq_cond1_lost: the average of relative frequency from lost dialogue reply in the condition 1
# 18. avg_relfreq_cond2_normal: the average of relative frequency from normal dialogue reply in the condition 2
# 19. avg_relfreq_cond2_short: the average of relative frequency from short dialogue reply in the condition 2
# 20. avg_relfreq_cond2_detail: the average of relative frequency from detail l dialogue reply in the condition 2
# 21. avg_relfreq_cond2_dont: the average of relative frequency from dont dialogue reply in the condition 2
# 22. avg_relfreq_cond2_lost: the average of relative frequency from lost dialogue reply in the condition 2
# 23. avg_relfreq_cond2_normal: the average of relative frequency from normal dialogue reply in the condition 2
# 24. avg_relfreq_cond2_short: the average of relative frequency from short dialogue reply in the condition 2
# 25. avg_relfreq_cond2_detail: the average of relative frequency from detail l dialogue reply in the condition 2
# 26. avg_relfreq_cond2_dont: the average of relative frequency from dont dialogue reply in the condition 2
# 27. avg_relfreq_cond2_lost: the average of relative frequency from lost dialogue reply in the condition 2

# File: data_long_process.csv
# 01. pid: participants ID number
# 02. gender: gender of participants
# 03. relfreq_coder1_detail: relative frequency of detail dialog reply from coder1's coded label
# 04. relfreq_coder2_detail: relative frequency of detail dialog reply from coder2's coded label
# 05. relfreq_coder3_detail: relative frequency of detail dialog reply from coder3's coded label
# 06. relfreq_coder1_normal: relative frequency of normal dialog reply from coder1's coded label
# 07. relfreq_coder2_normal: relative frequency of normal dialog reply from coder2's coded label
# 08. relfreq_coder3_normal: relative frequency of normal dialog reply from coder3's coded label
# 09. relfreq_coder1_short: relative frequency of short dialog reply from coder1's coded label
# 10. relfreq_coder2_short: relative frequency of short dialog reply from coder2's coded label
# 11. relfreq_coder3_short: relative frequency of short dialog reply from coder3's coded label
# 12. relfreq_coder1_dont: relative frequency of "dont know" dialog reply from coder1's coded label
# 13. relfreq_coder2_dont: relative frequency of "dont know" dialog reply from coder2's coded label
# 14. relfreq_coder3_dont: relative frequency of "dont know dialog reply from coder3's coded label
# 15. relfreq_coder1_lost: relative frequency of "lost in the dialog" from coder1's coded label
# 16. relfreq_coder2_lost: relative frequency of "lost in the dialog" from coder2's coded label
# 17. relfreq_coder3_lost: relative frequency of "lost in the dialog" from coder3's coded label

cat("\n\nLoading the wide data format...\n\n")
dataset_explore_wide <- read.csv("data_wide_process.csv")

cat("=== SEQ data ===\n\n")
cat("1. Have a look at the densities using histogram\n")
cat("Histogram SEQ condition 1 generated...\n")
histogram(dataset_explore_wide$total_seq_cond1, "SEQ condition 1", "SEQ")
cat("Histogram SEQ condition 2 generated...\n")
histogram(dataset_explore_wide$total_seq_cond2, "SEQ condition 2", "SEQ")
cat("Histogram SEQ condition 3 generated...\n")
histogram(dataset_explore_wide$total_seq_cond3, "SEQ condition 3", "SEQ")
# 2. Perform test
cat("\n2. Perform normality test\n")
cat("Normality test: Total SEQ in condition 1\n")
shapiro.test(dataset_explore_wide$total_seq_cond1)
cat("Normality test: Total SEQ in condition 2\n")
shapiro.test(dataset_explore_wide$total_seq_cond2)
cat("Normality test: Total SEQ in condition 3\n")
shapiro.test(dataset_explore_wide$total_seq_cond3)
# 3. Plot using a QQPLOT for normality checks
cat("\n3. Plot using a qqplot for normality checks\n")
cat("QQPlot/ normality plot of Total SEQ condition 1 generated...\n ")
qqnorm(dataset_explore_wide$total_seq_cond1, main = "Total SEQ condition 1");qqline(dataset_explore_wide$total_seq_cond1, col = 2)
cat("QQPlot/ normality plot of Total SEQ condition 2 generated...\n ")
qqnorm(dataset_explore_wide$total_seq_cond2, main = "Total SEQ condition 2");qqline(dataset_explore_wide$total_seq_cond2, col = 2)
cat("QQPlot/ normality plot of Total SEQ condition 3 generated...\n ")
qqnorm(dataset_explore_wide$total_seq_cond3, main = "Total SEQ condition 3");qqline(dataset_explore_wide$total_seq_cond3, col = 2)

# DEQ data
cat("\n=== DEQ data ===\n\n")
# 1. Have a look at the densities using histogram
cat("1. Have a look at the densities using histogram\n")
cat("Histogram DEQ condition 1 generated...\n")
histogram(dataset_explore_wide$total_deq_cond1, "DEQ condition 1", "DEQ")
cat("Histogram DEQ condition 2 generated...\n")
histogram(dataset_explore_wide$total_deq_cond2, "DEQ condition 2", "DEQ")
cat("Histogram DEQ condition 3 generated...\n")
histogram(dataset_explore_wide$total_deq_cond3, "DEQ condition 3", "DEQ")
# 2. Perform test
cat("\n2. Perform normality test")
cat("Normality test: Total DEQ in condition 1\n")
shapiro.test(dataset_explore_wide$total_deq_cond1)
cat("Normality test: Total DEQ in condition 2\n")
shapiro.test(dataset_explore_wide$total_deq_cond2)
cat("Normality test: Total DEQ in condition 3\n")
shapiro.test(dataset_explore_wide$total_deq_cond3)
# 3. Plot using a qqplot for normality checks
cat("\n3. Plot using a QQPLOT for normality checks\n")
cat("QQPlot/ normality plot of Total DEQ condition 1 generated...\n ")
qqnorm(dataset_explore_wide$total_deq_cond1, main = "Total DEQ condition 1");qqline(dataset_explore_wide$total_deq_cond1, col = 2)
cat("QQPlot/ normality plot of Total DEQ condition 2 generated...\n ")
qqnorm(dataset_explore_wide$total_deq_cond2, main = "Total DEQ condition 2");qqline(dataset_explore_wide$total_deq_cond2, col = 2)
cat("QQPlot/ normality plot of Total DEQ condition 3 generated...\n ")
qqnorm(dataset_explore_wide$total_deq_cond3, main = "Total DEQ condition 3");qqline(dataset_explore_wide$total_deq_cond3, col = 2)

# IPQ data
cat("\n === IPQ data ===\n")
# 1. Have a look at the densities using histogram
cat("1. Have a look at the densities using histogram\n")
cat("Histogram IPQ condition 1 generated...\n")
histogram(dataset_explore_wide$total_ipq_cond1, "IPQ condition 1", "IPQ")
cat("Histogram IPQ condition 2 generated...\n")
histogram(dataset_explore_wide$total_ipq_cond2, "IPQ condition 2", "IPQ")
cat("Histogram IPQ condition 3 generated...\n")
histogram(dataset_explore_wide$total_ipq_cond3, "IPQ condition 3", "IPQ")
# 2. Perform test
cat("\n2. Perform normality test")
cat("Normality test: Total IPQ in condition 1\n")
shapiro.test(dataset_explore_wide$total_ipq_cond1)
cat("Normality test: Total IPQ in condition 2\n")
shapiro.test(dataset_explore_wide$total_ipq_cond2)
cat("Normality test: Total IPQ in condition 3\n")
shapiro.test(dataset_explore_wide$total_ipq_cond3)
# 3. Plot using a qqplot for normality checks
cat("\n3. Plot using a QQPLOT for normality checks\n")
cat("QQPlot/ normality plot of Total IPQ condition 1 generated...\n ")
qqnorm(dataset_explore_wide$total_ipq_cond1, main = "Total IPQ condition 1");qqline(dataset_explore_wide$total_ipq_cond1, col = 2)
cat("QQPlot/ normality plot of Total IPQ condition 2 generated...\n ")
qqnorm(dataset_explore_wide$total_ipq_cond2, main = "Total IPQ condition 1");qqline(dataset_explore_wide$total_ipq_cond2, col = 2)
cat("QQPlot/ normality plot of Total IPQ condition 3 generated...\n ")
qqnorm(dataset_explore_wide$total_ipq_cond3, main = "Total IPQ condition 1");qqline(dataset_explore_wide$total_ipq_cond3, col = 2)


cat("\n\n * Check data distribution of average relative frequency on 3 timing mechanism condition.* \n")
#condition 1
cat("\ncondition 1 \n")
cat("Histogram Means relative frequency [detail answer] in condition 1 generated...\n")
histogram(dataset_explore_wide$avg_relfreq_cond1_detail, "cond 1: [Detail]", "AVG relative frequency")
cat("Histogram Means relative frequency [normal answer] in condition 1 generated...\n")
histogram(dataset_explore_wide$avg_relfreq_cond1_normal, "cond 1: [Normal]", "AVG relative frequency")
cat("Histogram Means relative frequency [short answer] in condition 1 generated...\n")
histogram(dataset_explore_wide$avg_relfreq_cond1_short, "cond 1: [Short]", "AVG relative frequency")
cat("Histogram Means relative frequency [dont know answer] in condition 1 generated...\n")
histogram(dataset_explore_wide$avg_relfreq_cond1_dont, "cond 1: [Don't]", "AVG relative frequency")
cat("Histogram Means relative frequency [lost in the dialog answer] in condition 1 generated...\n")
histogram(dataset_explore_wide$avg_relfreq_cond1_lost, "cond 1: [Lost in dialog]", "AVG relative frequency")

#condition 2
cat("\ncondition 2 \n")
cat("Histogram Means relative frequency [detail answer] in condition 2 generated...\n")
histogram(dataset_explore_wide$avg_relfreq_cond2_detail, "cond 2: [Detail]", "AVG relative frequency")
cat("Histogram Means relative frequency [normal answer] in condition 2 generated...\n")
histogram(dataset_explore_wide$avg_relfreq_cond2_normal, "cond 2: [Normal]", "AVG relative frequency")
cat("Histogram Means relative frequency [short answer] in condition 2 generated...\n")
histogram(dataset_explore_wide$avg_relfreq_cond2_short, "cond 2: [Short]", "AVG relative frequency")
cat("Histogram Means relative frequency [dont know answer] in condition 2 generated...\n")
histogram(dataset_explore_wide$avg_relfreq_cond2_dont, "cond 2: [Don't]", "AVG relative frequency")
cat("Histogram Means relative frequency [lost in the dialog answer] in condition 2 generated...\n")
histogram(dataset_explore_wide$avg_relfreq_cond2_lost, "cond 2: [Lost in dialog]", "AVG relative frequency")

#condition 3
cat("\ncondition 3 \n")
cat("Histogram Means relative frequency [detail answer] in condition 3 generated...\n")
histogram(dataset_explore_wide$avg_relfreq_cond3_detail, "cond 3: [Detail]", "AVG relative frequency")
cat("Histogram Means relative frequency [normal answer] in condition 3 generated...\n")
histogram(dataset_explore_wide$avg_relfreq_cond3_normal, "cond 3: [Normal]", "AVG relative frequency")
cat("Histogram Means relative frequency [short answer] in condition 3 generated...\n")
histogram(dataset_explore_wide$avg_relfreq_cond3_short, "cond 3: [Short]", "AVG relative frequency")
cat("Histogram Means relative frequency [dont know answer] in condition 3 generated...\n")
histogram(dataset_explore_wide$avg_relfreq_cond3_dont, "cond 3: [Don't]", "AVG relative frequency")
cat("Histogram Means relative frequency [lost in the dialog answer] in condition 3 generated...\n")
histogram(dataset_explore_wide$avg_relfreq_cond3_lost, "cond 3: [Lost in dialog]", "AVG relative frequency")

cat("\nNote: since the data is not normally distributed, then we will do non-paramatric test for further analyses later in the chapter. \n\n")

# Levene's test for equal variances from three coder in each coded dialog
cat("* Levene's test for equal variances from three coder in each coded dialog * \n\n")
dataset_explore_long <- read.csv("data_long_process.csv")

# Detail answer
cat("=== Detail answer ===\n")
levene_test(dataset_explore_long$relfreq_coder1_detail, dataset_explore_long$relfreq_coder2_detail, "Detail: relative freq. coder 1 and coder 2\n")
levene_test(dataset_explore_long$relfreq_coder1_detail, dataset_explore_long$relfreq_coder3_detail, "Detail: relative freq. coder 1 and coder 3\n")
levene_test(dataset_explore_long$relfreq_coder2_detail, dataset_explore_long$relfreq_coder3_detail, "Detail: relative freq. coder 2 and coder 3\n")
# Normal answer
cat("=== Normal answer ===\n")
levene_test(dataset_explore_long$relfreq_coder1_normal, dataset_explore_long$relfreq_coder2_normal, "Normal: relative freq. coder 1 and coder 2\n")
levene_test(dataset_explore_long$relfreq_coder1_normal, dataset_explore_long$relfreq_coder3_normal, "Normal: relative freq. coder 1 and coder 3\n")
levene_test(dataset_explore_long$relfreq_coder2_normal, dataset_explore_long$relfreq_coder3_normal, "Normal: relative freq. coder 2 and coder 3\n")
# Short answer
cat("=== Short answer ===\n")
levene_test(dataset_explore_long$relfreq_coder1_short, dataset_explore_long$relfreq_coder2_short, "Short: relative freq. coder 1 and coder 2\n")
levene_test(dataset_explore_long$relfreq_coder1_short, dataset_explore_long$relfreq_coder3_short, "Short: relative freq. coder 1 and coder 3\n")
levene_test(dataset_explore_long$relfreq_coder2_short, dataset_explore_long$relfreq_coder3_short, "Short: relative freq. coder 2 and coder 3\n")
# Dont know answer
cat("=== Dont know answer ===")
levene_test(dataset_explore_long$relfreq_coder1_dont, dataset_explore_long$relfreq_coder2_dont, "Dont know: relative freq. coder 1 and coder 2\n")
levene_test(dataset_explore_long$relfreq_coder1_dont, dataset_explore_long$relfreq_coder3_dont, "Dont know: relative freq. coder 1 and coder 3\n")
levene_test(dataset_explore_long$relfreq_coder2_dont, dataset_explore_long$relfreq_coder3_dont, "Dont know: relative freq. coder 2 and coder 3\n")
# Lost in the dialog
cat("=== Lost in the dialog ===\n")
levene_test(dataset_explore_long$relfreq_coder1_lost, dataset_explore_long$relfreq_coder2_lost, "Lost: relative freq. coder 1 and coder 2\n")
levene_test(dataset_explore_long$relfreq_coder1_lost, dataset_explore_long$relfreq_coder3_lost, "Lost: relative freq. coder 1 and coder 3\n")
levene_test(dataset_explore_long$relfreq_coder2_lost, dataset_explore_long$relfreq_coder3_lost, "Lost: relative freq. coder 2 and coder 3\n")

######### stop redireting output.
sink()

cat("\n\nOutput of this R script file: data_explore_automatic_mechanism_for_measuring_subjective_unit_of_discomfort.txt") 








